@@ -93,14 +93,9 @@ class Manager(manager.Manager):
     def get_trust_pedigree(self, trust_id):
         trust = self.driver.get_trust(trust_id)
         trust_chain = [trust]
-        if trust and trust.get('redelegated_trust_id'):
-            trusts = self.driver.list_trusts_for_trustor(
-                trust['trustor_user_id'])
-            while trust_chain[-1].get('redelegated_trust_id'):
-                for t in trusts:
-                    if t['id'] == trust_chain[-1]['redelegated_trust_id']:
-                        trust_chain.append(t)
-                        break
+        while trust and trust.get('redelegated_trust_id'):
+            trust = self.driver.get_trust(trust['redelegated_trust_id'])
+            trust_chain.append(trust)
 
         return trust_chain
 
